summaryrefslogtreecommitdiffstats
path: root/tdecore/kinstance.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-22 20:20:05 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-22 20:20:05 -0600
commitb19ddece21e102b8e4b292037ca7578f60b128fe (patch)
tree6572ca25aba80849cdfa7578bbbc9121d23afbc3 /tdecore/kinstance.h
parente729c6d549f12e27b358a1dad04ff254c033ac71 (diff)
downloadtdelibs-b19ddece21e102b8e4b292037ca7578f60b128fe.tar.gz
tdelibs-b19ddece21e102b8e4b292037ca7578f60b128fe.zip
Rename KInstance and KAboutData to avoid conflicts with KDE4
Diffstat (limited to 'tdecore/kinstance.h')
-rw-r--r--tdecore/kinstance.h34
1 files changed, 17 insertions, 17 deletions
diff --git a/tdecore/kinstance.h b/tdecore/kinstance.h
index 2d94d10c1..36d463d8a 100644
--- a/tdecore/kinstance.h
+++ b/tdecore/kinstance.h
@@ -19,12 +19,12 @@
#define _KINSTANCE_H
class KStandardDirs;
-class KAboutData;
+class TDEAboutData;
class KConfig;
class KIconLoader;
class KCharsets;
class TQFont;
-class KInstancePrivate;
+class TDEInstancePrivate;
class KMimeSourceFactory;
class KSharedConfig;
class TDEHardwareDevices;
@@ -42,7 +42,7 @@ class TDEGlobalNetworkManager;
*
* @author Torben Weis
*/
-class TDECORE_EXPORT KInstance
+class TDECORE_EXPORT TDEInstance
{
friend class KStandardDirs;
@@ -51,19 +51,19 @@ class TDECORE_EXPORT KInstance
* Constructor.
* @param instanceName the name of the instance
*/
- KInstance( const TQCString& instanceName) ;
+ TDEInstance( const TQCString& instanceName) ;
/**
* Constructor.
* When building a KInstance that is not your TDEApplication,
* make sure that the KAboutData and the KInstance have the same life time.
* You have to destroy both, since the instance doesn't own the about data.
* Don't build a KAboutData on the stack in this case !
* Building a KAboutData on the stack is only ok for usage with
* TDECmdLineArgs and TDEApplication (not destroyed until the app exits).
* @param aboutData data about this instance (see KAboutData)
*/
- KInstance( const KAboutData * aboutData );
+ TDEInstance( const TDEAboutData * aboutData );
/*
* @internal
@@ -71,12 +71,12 @@ class TDECORE_EXPORT KInstance
* Initialize from src and delete it.
*/
- KInstance( KInstance* src );
+ TDEInstance( TDEInstance* src );
/**
* Destructor.
*/
- virtual ~KInstance();
+ virtual ~TDEInstance();
/**
* Returns the application standard dirs object.
@@ -133,11 +133,11 @@ class TDECORE_EXPORT KInstance
* @return the about data of the instance, or 0 if it has
* not been set yet
*/
- const KAboutData *aboutData() const;
+ const TDEAboutData *aboutData() const;
/**
* Returns the name of the instance
* @return the instance name, can be null if the KInstance has been
* created with a null name
*/
TQCString instanceName() const;
@@ -153,7 +153,7 @@ protected:
/**
* Copy Constructor is not allowed
*/
- KInstance( const KInstance& );
+ TDEInstance( const TDEInstance& );
/**
* Set name of default config file.
@@ -173,12 +173,12 @@ private:
mutable void *_placeholder;
TQCString _name;
- const KAboutData *_aboutData;
+ const TDEAboutData *_aboutData;
protected:
virtual void virtual_hook( int id, void* data );
private:
- KInstancePrivate *d;
+ TDEInstancePrivate *d;
bool m_configReadOnly;
};
@@ -51,19 +51,19 @@ class TDECORE_EXPORT KInstance
/**
* Constructor.
- * When building a KInstance that is not your TDEApplication,
- * make sure that the KAboutData and the KInstance have the same life time.
+ * When building a TDEInstance that is not your TDEApplication,
+ * make sure that the TDEAboutData and the TDEInstance have the same life time.
* You have to destroy both, since the instance doesn't own the about data.
@@ -51,19 +51,19 @@ class TDECORE_EXPORT KInstance
* You have to destroy both, since the instance doesn't own the about data.
- * Don't build a KAboutData on the stack in this case !
- * Building a KAboutData on the stack is only ok for usage with
+ * Don't build a TDEAboutData on the stack in this case !
+ * Building a TDEAboutData on the stack is only ok for usage with
* TDECmdLineArgs and TDEApplication (not destroyed until the app exits).
@@ -51,19 +51,19 @@ class TDECORE_EXPORT KInstance
* TDECmdLineArgs and TDEApplication (not destroyed until the app exits).
- * @param aboutData data about this instance (see KAboutData)
+ * @param aboutData data about this instance (see TDEAboutData)
*/
@@ -133,11 +133,11 @@ class TDECORE_EXPORT KInstance
/**
* Returns the name of the instance
- * @return the instance name, can be null if the KInstance has been
+ * @return the instance name, can be null if the TDEInstance has been
* created with a null name
*/